@@ -1,5 +1,6 @@
 
 from mezzanine import template
+from mezzanine.generic.fields import RatingField
 from mezzanine.generic.forms import RatingForm
 
 
@@ -12,6 +13,11 @@ def rating_for(context, obj):
     Provides a generic context variable name for the object that
     ratings are being rendered for, and the rating form.
     """
-    context["object_for_rating"] = obj
-    context["form_for_rating"] = RatingForm(obj)
+    context["rating_obj"] = obj
+    context["rating_form"] = RatingForm(obj)
+    for field in obj._meta.many_to_many:
+        if isinstance(field, RatingField):
+            context["rating_average"] = getattr(obj, "%s_average" % field.name)
+            context["rating_count"] = getattr(obj, "%s_count" % field.name)
+            break
     return context
