@@ -44,7 +44,7 @@ def admin_page_ordering(request):
 admin_page_ordering = staff_member_required(admin_page_ordering)
 
 
-def page(request, slug, template="pages/page.html", extra_context=None):
+def page(request, slug, template=u"pages/page.html", extra_context=None):
     """
     Select a template for a page and render it. The ``extra_context``
     arg will include a ``page`` object that's added via
@@ -53,6 +53,15 @@ def page(request, slug, template="pages/page.html", extra_context=None):
     the current page can include a page in their template context.
     The urlpattern that maps to this view is a catch-all pattern, in
     which case the page instance will be None, so raise a 404 then.
+
+    For template selection, a list of possible templates is built up
+    based on the current page. This list is order from most granular
+    match, starting with a custom template for the exact page, then
+    adding templates based on the page's parent page, that could be
+    used for sections of a site (eg all children of the parent).
+    Finally at the broadest level, a template for the page's content
+    type (it's model class) is checked for, and then if none of these
+    templates match, the default pages/page.html is used.
     """
     page_middleware = "mezzanine.pages.middleware.PageMiddleware"
     if page_middleware not in settings.MIDDLEWARE_CLASSES:
@@ -64,11 +73,21 @@ def page(request, slug, template="pages/page.html", extra_context=None):
         page = extra_context["page"]
     except KeyError:
         raise Http404
+
     # Check for a template name matching the page's slug. If the homepage
     # is configured as a page instance, the template "pages/index.html" is
     # used, since the slug "/" won't match a template name.
     template_name = unicode(slug) if slug != "/" else "index"
     templates = [u"pages/%s.html" % template_name]
+    if page.content_model is not None:
+        templates.append(u"pages/%s/%s.html" % (template_name,
+            page.content_model))
+    for parent in page.get_ascendants():
+        parent_template_name = unicode(parent.slug)
+        # Check for a template matching the page's content model.
+        if page.content_model is not None:
+            templates.append(u"pages/%s/%s.html" % (parent_template_name,
+                page.content_model))
     # Check for a template matching the page's content model.
     if page.content_model is not None:
         templates.append(u"pages/%s.html" % page.content_model)
