@@ -9,7 +9,7 @@ from mezzanine.utils.importing import path_for_import
 
 
 # Ignore these warnings in pyflakes - if added to, please comment why.
-PYFLAKES_IGNORE = (
+IGNORE_ERRORS = (
 
     # local_settings import.
     "'from local_settings import *' used",
@@ -33,6 +33,10 @@ PYFLAKES_IGNORE = (
     # Fabic config fallback
     "redefinition of unused 'conf'",
 
+    # Fixing these would make the code ugiler IMO.
+    "continuation line",
+    "closing bracket does not match",
+
 )
 
 
@@ -57,11 +61,14 @@ def copy_test_to_media(module, name):
         pass
 
 
-def _run_checker_for_package(checker, package_name):
+def _run_checker_for_package(checker, package_name, extra_ignore=None):
     """
     Runs the checker function across every Python module in the
     given package.
     """
+    ignore_strings = IGNORE_ERRORS
+    if extra_ignore:
+        ignore_strings += extra_ignore
     package_path = path_for_import(package_name)
     for (root, dirs, files) in os.walk(package_path):
         for f in files:
@@ -71,7 +78,11 @@ def _run_checker_for_package(checker, package_name):
                 or directory == "migrations"):
                 continue
             for warning in checker(os.path.join(root, f)):
-                yield warning.replace(package_path, package_name, 1)
+                for ignore in ignore_strings:
+                    if ignore in warning:
+                        break
+                else:
+                    yield warning.replace(package_path, package_name, 1)
 
 
 def run_pyflakes_for_package(package_name, extra_ignore=None):
@@ -80,9 +91,6 @@ def run_pyflakes_for_package(package_name, extra_ignore=None):
     returning any warnings found.
     """
     from pyflakes.checker import Checker
-    ignore_strings = PYFLAKES_IGNORE
-    if extra_ignore:
-        ignore_strings += extra_ignore
 
     def pyflakes_checker(path):
         with open(path, "U") as source_file:
@@ -95,31 +103,28 @@ def run_pyflakes_for_package(package_name, extra_ignore=None):
         else:
             result = Checker(tree, path)
             for warning in result.messages:
-                message = unicode(warning)
-                for ignore in ignore_strings:
-                    if ignore in message:
-                        break
-                else:
-                    yield message
+                yield unicode(warning)
 
-    return _run_checker_for_package(pyflakes_checker, package_name)
+    args = (pyflakes_checker, package_name, extra_ignore)
+    return _run_checker_for_package(*args)
 
 
-def run_pep8_for_package(package_name):
+def run_pep8_for_package(package_name, extra_ignore=None):
     """
     If pep8 is installed, run it across the given package name
     returning any warnings or errors found.
     """
     import pep8
-    package_path = path_for_import(package_name)
-    pep8.process_options(["-r", package_path])
 
     class Checker(pep8.Checker):
         """
         Subclass pep8's Checker to hook into error reporting.
         """
+        def __init__(self, *args, **kwargs):
+            super(Checker, self).__init__(*args, **kwargs)
+            self.report_error = self._report_error
 
-        def report_error(self, line_number, offset, text, check):
+        def _report_error(self, line_number, offset, text, check):
             """
             Store pairs of line numbers and errors.
             """
@@ -137,4 +142,5 @@ def run_pep8_for_package(package_name):
         for line_number, text in Checker(path).check_all():
             yield "%s:%s: %s" % (path, line_number, text)
 
-    return _run_checker_for_package(pep8_checker, package_name)
+    args = (pep8_checker, package_name, extra_ignore)
+    return _run_checker_for_package(*args)
